==> jruby_9.3.9.0%2Bds.orig.tar.xz: jruby-9.3.9.0/test/mri/excludes/TestCoverage.rb <==
exclude :test_branch_coverage_for_case_statement, "no support for coverage options yet (#5147)"
exclude :test_branch_coverage_for_if_statement, "no support for coverage options yet (#5147)"
exclude :test_branch_coverage_for_safe_method_invocation, "no support for coverage options yet (#5147)"
exclude :test_branch_coverage_for_while_statement, "no support for coverage options yet (#5147)"
exclude :test_clear_with_branches, "no support for coverage options yet (#5147, #6149)"
exclude :test_clear_with_lines, "no support for coverage options yet (#5147, #6149)"
exclude :test_clear_with_methods, "no support for coverage options yet (#5147, #6149)"
exclude :test_clear_with_oneshot_lines, "no support for coverage options yet (#5147, #6149)"
exclude :test_coverage_optimized_branch, "no support for coverage options yet (#5147, #6149)"
exclude :test_eval, "line number is not matching in eval"
exclude :test_line_coverage_for_multiple_lines, "no support for coverage options yet (#5147)"
exclude :test_line_stub, "no support for coverage options yet (#5147, #6149)"
exclude :test_method_coverage, "no support for coverage options yet (#5147)"
exclude :test_method_coverage_for_alias, "no support for coverage options yet (#5147)"
exclude :test_method_coverage_for_define_method, "no support for coverage options yet (#5147)"
exclude :test_method_coverage_for_singleton_class, "no support for coverage options yet (#5147)"
exclude :test_nonpositive_linenumber, "requires RubyVM to compile iseq"
exclude :test_oneshot_line_coverage, "no support for coverage options yet (#5147, #6149)"
exclude :test_stop_wrong_peephole_optimization, "needs investigation"

==> jruby_9.4.8.0%2Bds.orig.tar.xz: jruby-9.4.8.0/test/mri/excludes/TestCoverage.rb <==
exclude :test_coverage_with_asan, "needs investigation"
exclude :test_method_coverage_for_define_method, "no support for coverage options yet (#5147)"
exclude :test_branch_coverage_for_pattern_matching, "no support for branches yet"
exclude :test_method_coverage_for_singleton_class, "no support for coverage options yet (#5147)"
exclude :test_clear_with_methods, "no support for coverage options yet (#5147, #6149)"
exclude :test_branch_coverage_in_ensure_clause, "no support for branches yet"
exclude :test_branch_coverage_for_case_statement, "no support for coverage options yet (#5147)"
exclude :test_coverage_optimized_branch, "no support for coverage options yet (#5147, #6149)"
exclude :test_line_coverage_for_multiple_lines, "needs investigation"
exclude :test_branch_coverage_for_safe_method_invocation, "no support for coverage options yet (#5147)"
exclude :test_branch_coverage_for_if_statement, "no support for coverage options yet (#5147)"
exclude :test_oneshot_line_coverage, "no support for coverage options yet (#5147, #6149)"
exclude :test_coverage_suspendable, "needs branching support"
exclude :test_stop_wrong_peephole_optimization, "needs investigation"
exclude :test_method_coverage, "no support for coverage options yet (#5147)"
exclude :test_branch_coverage_for_while_statement, "no support for coverage opit
ons yet (#5147)"
exclude :test_eval, "line number is not matching in eval"
exclude :test_clear_with_branches, "no support for coverage options yet (#5147, #6149)"
exclude :test_method_coverage_for_alias, "no support for coverage options yet (#5147)"
